/**
 * Linkchecker panel
 *
 * @module package/quiqqer/health/bin/controls/Linkchecker
 * @author www.pcsg.de (Henning Leutz)
 *
 * @require qui/QUI
 * @require qui/controls/Control
 * @require controls/grid/Grid
 * @require Locale
 * @require Ajax
 * @require package/quiqqer/health/bin/classes/Linkchecker
 * @require css!package/quiqqer/health/bin/controls/Linkchecker.css
 *
 * @event onLoaded
 */
define('package/quiqqer/health/bin/controls/Linkchecker', [

    'qui/QUI',
    'qui/controls/Control',
    'qui/controls/buttons/Select',
    'controls/grid/Grid',
    'Locale',
    'package/quiqqer/health/bin/classes/Linkchecker',

    'css!package/quiqqer/health/bin/controls/Linkchecker.css'

], function (QUI, QUIControl, QUISelect, Grid, QUILocale, Handler) {
    "use strict";

    var lg          = 'quiqqer/health',
        Linkchecker = new Handler();

    return new Class({

        Extends: QUIControl,
        Type   : 'package/quiqqer/health/bin/controls/Linkchecker',

        Binds: [
            'create',
            '$onInject'
        ],

        initialize: function (options) {
            this.parent(options);

            this.$Grid   = null;
            this.$Select = null;

            this.addEvents({
                onInject: this.$onInject
            });
        },

        /**
         * Creat the domnode element
         */
        create: function () {
            var Elm = this.parent();

            Elm.addClass('quiqqer-health-linkchecker');

            return Elm;
        },

        /**
         * resize
         */
        resize: function () {
            if (!this.$Grid) {
                return;
            }

            var size = this.getElm().getSize();

            this.$Grid.setHeight(size.y);
            this.$Grid.setWidth(size.x);
        },

        /**
         * event : on inject
         */
        $onInject: function () {
            var self = this;

            // grid
            var Container = new Element('div').inject(
                this.getElm()
            );

            this.$Grid = new Grid(Container, {
                pagination : true,
                columnModel: [{
                    header   : QUILocale.get('quiqqer/system', 'status'),
                    dataIndex: 'status',
                    dataType : 'number',
                    width    : 60
                }, {
                    header   : QUILocale.get('quiqqer/system', 'id'),
                    dataIndex: 'id',
                    dataType : 'number',
                    width    : 60
                }, {
                    header   : QUILocale.get('quiqqer/system', 'date'),
                    dataIndex: 'date',
                    dataType : 'date',
                    width    : 140
                }, {
                    header   : QUILocale.get('quiqqer/system', 'project'),
                    dataIndex: 'project',
                    dataType : 'string',
                    width    : 100
                }, {
                    header   : QUILocale.get('quiqqer/system', 'lang'),
                    dataIndex: 'lang',
                    dataType : 'string',
                    width    : 100
                }, {
                    header   : QUILocale.get(lg, 'linkchecker.grid.sitesCounts'),
                    dataIndex: 'siteidsCount',
                    dataType : 'number',
                    width    : 100
                }, {
                    header   : QUILocale.get(lg, 'linkchecker.grid.doneCount'),
                    dataIndex: 'doneCount',
                    dataType : 'number',
                    width    : 100
                }]
            });

            this.$Grid.addEvents({
                onDblClick: function () {
                    self.openJob(
                        self.$Grid.getSelectedData().id
                    );
                }
            });

            this.refresh().then(function () {
                self.fireEvent('loaded', [self]);
            });
        },

        /**
         * refresh
         *
         * @returns {Promise}
         */
        refresh: function () {
            var self = this;

            return new Promise(function (resolve, reject) {

                Linkchecker.getJobs({
                    perPage: self.$Grid.options.perPage,
                    page   : self.$Grid.options.page
                }).then(function (data) {
                    self.$Grid.setData(data);
                    resolve();
                }).catch(reject);
            });

        },

        /**
         *
         * @param {Number} jobId
         */
        openJob: function (jobId) {
            cnsole.log(jobId);
        }

    });
});
