/**
 * Health panel
 *
 * @module package/quiqqer/health/bin/controls/Panel
 * @author www.pcsg.de (Henning Leutz)
 *
 * @require qui/QUI
 * @require qui/controls/desktop/Panel
 */
define('package/quiqqer/health/bin/controls/Panel', [

    'qui/QUI',
    'qui/controls/desktop/Panel',
    'Locale'

], function (QUI, QUIPanel, QUILocale) {
    "use strict";

    return new Class({

        Extends: QUIPanel,
        Type   : 'package/quiqqer/health/bin/controls/Panel',

        Binds: [
            '$onCreate',
            '$onInject',
            '$onResize',
            'openLinkchecker'
        ],

        initialize: function (options) {
            var self = this;

            this.setAttributes({
                title: QUILocale.get('quiqqer/health', 'health.panel.title'),
                icon : 'fa-heartbeat'
            });

            this.parent(options);

            this.$Active = null;

            this.addEvents({
                onCreate: this.$onCreate,
                onInject: this.$onInject,
                onResize: this.$onResize,
                onShow  : function () {
                    (function () {
                        self.$onResize();
                    }).delay(200);
                }
            });
        },

        /**
         * event : on create
         */
        $onCreate: function () {
            this.addCategory({
                name  : 'linkchecker',
                text  : 'Linkchecker',
                icon  : 'fa fa-link',
                events: {
                    onClick: this.openLinkchecker

                }
            });
        },

        /**
         * event : on inject
         */
        $onInject: function () {
            this.getCategory('linkchecker').click();
        },

        /**
         * event : on resize
         */
        $onResize: function () {
            if (this.$Active) {
                this.$Active.resize();
            }
        },

        /**
         * opens the linkchecker
         */
        openLinkchecker: function () {
            var self = this;

            //this.Loader.show();
            this.getContent().set('html', '');
            this.getCategory('linkchecker').setActive();

            require([
                'package/quiqqer/health/bin/controls/Linkchecker'
            ], function (Linkchecker) {
                self.$Active = new Linkchecker({
                    events: {
                        onLoaded: function (Control) {
                            self.Loader.hide();
                            Control.resize();
                        }
                    }
                }).inject(self.getContent());
            });
        }

    });
});
