<?php

/**
 * This file contains QUI\Health\Project
 */
namespace QUI\Health;

use QUI;
use QUI\Projects\Project;

/**
 * Class Linkchecker
 *
 * @package QUI\Health
 */
class Linkchecker
{
    /**
     * Create a new linkchecker job
     *
     * @param Project $Project
     * @return QUI\Health\Linkchecker\Job
     */
    public function createJob(Project $Project)
    {
        $Checker = new Linkchecker\Handler();

        $Job = $Checker->createChild(array(
            'project' => $Project->getName(),
            'lang' => $Project->getLang(),
            'date' => date('Y-m-d H:i:s')
        ));

        return $Job;
    }

    /**
     * @param integer $linkcheckerJobId
     */
    public function runJob($linkcheckerJobId)
    {
        /* @var $Job QUI\Health\Linkchecker\Job */
        $Checker = new Linkchecker\Handler();
        $Job     = $Checker->getChildren($linkcheckerJobId);

        $Job->execute();
    }

    /**
     * Return all unfinished linkchecker jobs
     *
     * @return array
     */
    public function getUnfinishedJobs()
    {
        $Checker = new Linkchecker\Handler();

        return $Checker->getChildren(array(
            'where' => array(
                'status' => 0
            )
        ));
    }

    /**
     * Send the result of a test via E-Mail
     *
     * @param string $email
     * @param integer $testId
     *
     * @throws QUI\Exception
     */
    public function sendResultMail($email, $testId)
    {
        $Checker = new Linkchecker\Handler();

        $result = QUI::getDataBase()->fetch(array(
            'from' => $Checker->getDataBaseTableName(),
            'where' => array(
                'jobId' => $testId
            )
        ));

        if (!isset($result[0])) {
            throw new QUI\Exception(array(
                'quiqqer/health',
                'exception.linkchecker.test.not.found'
            ));
        }

        $Engine = QUI::getTemplateManager()->getEngine();

        $Engine->assign(array(
            'sitesCount' => count($result),
            'result' => $result
        ));

        $body   = $Engine->fetch(dirname(__FILE__) . '/Linkchecker/mails/result.html');
        $Mailer = QUI::getMailManager()->getMailer();

        $Mailer->addRecipient($email);
        $Mailer->setSubject('Linkchecker result');
        $Mailer->setBody($body);
        $Mailer->send();
    }
}
