<?php

/**
 * This file contains QUI\Health\Linkchecker\Utils\Url
 */
namespace QUI\Health\Linkchecker\Utils;

use QUI;
use QUI\Utils\Request\Url as QUIUrl;

/**
 * Class Url
 * @package QUI\Health
 */
class Url
{
    const USER_AGENT = 'QUIQQER LinkChecker (http://www.quiqqer.com/)';

    /**
     * Crawlt alle Links einer URL
     *
     * @param String $url - Zum Beispiel: http://www.pcsg.de/Startseite.html
     * @return array
     */
    public static function getLinksFromUrl($url)
    {
        // @todo must be better implemented
        $url = str_replace(array(
            'ä',
            'ö',
            'ü',
            'ß'
        ), array(
            '%C3%A4',
            '%C3%B6',
            '%C3%BC',
            '%C3%9F'
        ), $url);

        $content = self::getContent($url);
        $result  = array();

        $Dom = new \DOMDocument();

        try {
            // html5 errors
            libxml_use_internal_errors(true);
            $Dom->loadHTML($content);
            libxml_clear_errors();

        } catch (\Exception $Exception) {
            QUI\System\Log::addError($Exception->getMessage());
        }

        $parseUrl = parse_url($url);

        if (!isset($parseUrl['host'])) {
            $parseUrl['host'] = '';
        }

        if (!isset($parseUrl['scheme'])) {
            $parseUrl['scheme'] = 'http';
        }

        $host = $parseUrl['scheme'] . '://' . $parseUrl['host'] . '/';

        // Alle Links in der Seite
        $XPath = new \DOMXPath($Dom);
        $links = $XPath->evaluate("/html/body//a");

        for ($i = 0, $len = $links->length; $i < $len; $i++) {
            /* @var $Link \DOMElement */
            $Link = $links->item($i);
            $href = $Link->getAttribute('href');

            // Mails überspringen
            if (strpos($href, 'mailto:') !== false) {
                continue;
            }

            // JS überspringen
            if (strpos($href, 'javascript:') !== false) {
                continue;
            }

            // Relativen Links in absolute Umwandeln
            if (strpos($href, '/') == 0) {
                $href = $host . trim($href, '/');
            }

            if (strpos($href, '://') === false) {
                $href = $host . trim($href, '/');
            }

            $innerhtml = QUI\Utils\DOM::getInnerHTML($Link);

            $result[] = array(
                'url' => empty($href) ? false : $href,
                'empty' => empty($innerhtml) ? true : false,
                'value' => $innerhtml
            );
        }

        return $result;
    }

    /**
     * Checks the http code of an url
     *
     * @param string $url - Zum Beispiel: http://www.quiqqer.com/contact
     * @return integer
     */
    public static function checkUrl($url)
    {
        $Curl = QUIUrl::curl($url, array(
            \CURLOPT_USERAGENT => self::USER_AGENT
        ));

        $data     = curl_exec($Curl);
        $httpCode = curl_getinfo($Curl, \CURLINFO_HTTP_CODE);

        // timeout nicht als Fehler behandeln
        $error = curl_error($Curl);

        if ($error == 'connect() timed out'
            || $error == "couldn't connect to host"
        ) {
            $httpCode = 200;
        }

        // Error
        if (empty($data) && empty($httpCode)) {
            $httpCode = 1000;
        }

        curl_close($Curl);

        return $httpCode;
    }

    /**
     * Return the content from an url
     *
     * @param string $url
     * @return string
     */
    public static function getContent($url)
    {
        $Curl = QUIUrl::curl($url, array(
            \CURLOPT_USERAGENT => self::USER_AGENT
        ));

        return curl_exec($Curl);
    }
}
